==> messagelib-16.12.0.tar.xz: messagelib-16.12.0/messageviewer/src/scamdetection/scamcheckshorturlmanager.cpp <==
/*
  Copyright (c) 2016 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#include "scamcheckshorturl.h"
#include "scamcheckshorturlmanager.h"

using namespace MessageViewer;

class ScamCheckShortUrlManagerInstancePrivate
{
public:
    ScamCheckShortUrlManagerInstancePrivate()
        : scamCheckShortUrlManager(new ScamCheckShortUrlManager)
    {
    }

    ~ScamCheckShortUrlManagerInstancePrivate()
    {
        delete scamCheckShortUrlManager;
    }

    ScamCheckShortUrlManager *scamCheckShortUrlManager;
};

Q_GLOBAL_STATIC(ScamCheckShortUrlManagerInstancePrivate, sInstance)

class MessageViewer::ScamCheckShortUrlManagerPrivate
{
public:
    ScamCheckShortUrlManagerPrivate()
        : mCheckShortUrl(Q_NULLPTR)
    {

    }
    ScamCheckShortUrl *mCheckShortUrl;
};

ScamCheckShortUrlManager::ScamCheckShortUrlManager(QObject *parent)
    : QObject(parent),
      d(new ScamCheckShortUrlManagerPrivate)
{
    d->mCheckShortUrl = new ScamCheckShortUrl(this);
}

ScamCheckShortUrlManager::~ScamCheckShortUrlManager()
{
    delete d;
}

ScamCheckShortUrlManager *ScamCheckShortUrlManager::self()
{
    return sInstance->scamCheckShortUrlManager;
}

ScamCheckShortUrl *ScamCheckShortUrlManager::scamCheckShortUrl() const
{
    return d->mCheckShortUrl;
}

==> messagelib-17.04.1.tar.xz: messagelib-17.04.1/messageviewer/src/scamdetection/scamcheckshorturlmanager.cpp <==
/*
  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#include "scamcheckshorturl.h"
#include "scamcheckshorturlmanager.h"

using namespace MessageViewer;

class ScamCheckShortUrlManagerInstancePrivate
{
public:
    ScamCheckShortUrlManagerInstancePrivate()
        : scamCheckShortUrlManager(new ScamCheckShortUrlManager)
    {
    }

    ~ScamCheckShortUrlManagerInstancePrivate()
    {
        delete scamCheckShortUrlManager;
    }

    ScamCheckShortUrlManager *scamCheckShortUrlManager;
};

Q_GLOBAL_STATIC(ScamCheckShortUrlManagerInstancePrivate, sInstance)

class MessageViewer::ScamCheckShortUrlManagerPrivate
{
public:
    ScamCheckShortUrlManagerPrivate()
        : mCheckShortUrl(nullptr)
    {

    }
    ScamCheckShortUrl *mCheckShortUrl;
};

ScamCheckShortUrlManager::ScamCheckShortUrlManager(QObject *parent)
    : QObject(parent),
      d(new ScamCheckShortUrlManagerPrivate)
{
    d->mCheckShortUrl = new ScamCheckShortUrl(this);
}

ScamCheckShortUrlManager::~ScamCheckShortUrlManager()
{
    delete d;
}

ScamCheckShortUrlManager *ScamCheckShortUrlManager::self()
{
    return sInstance->scamCheckShortUrlManager;
}

ScamCheckShortUrl *ScamCheckShortUrlManager::scamCheckShortUrl() const
{
    return d->mCheckShortUrl;
}
